@@ -12,6 +12,9 @@ import sys
 # pytuple shortcut lambda:
 pytuple = lambda *attrs: tuple(f'__{atx}__' for atx in attrs)
 
+# Appname (née PROJECT_NAME):
+APPNAME = sys.intern('clu')
+
 # Project base path:
 BASEPATH = sys.intern(
            os.path.dirname(
@@ -34,6 +37,9 @@ DELETE_FLAG = getattr(os, 'O_TEMPORARY', 0)
 # Default terminal width:
 DEFAULT_TERMINAL_WIDTH = int(os.environ.get('COLUMNS', '100'), base=10)
 
+# Dollar-sign string (for use in regexing):
+DOLLA = sys.intern('$')
+
 # A prefix to use when creating new modules programmatically:
 DYNAMIC_MODULE_PREFIX = sys.intern('__dynamic_modules__')
 
@@ -43,6 +49,9 @@ ENCODING = sys.intern(sys.getfilesystemencoding().upper()) # 'UTF-8'
 # The environment-variable name partition separator:
 ENVIRONS_SEP = sys.intern('_')
 
+# The default exporter instance name:
+EXPORTER_NAME = sys.intern('exporter')
+
 # Possible names for file arguments (used for introspection):
 FILE_ARGUMENT_NAMES = ('path', 'pth', 'file')
 
@@ -60,7 +69,7 @@ MAXINT = getattr(sys, 'maxint',
          getattr(sys, 'maxsize', (2 ** 64) / 2))
 
 # The namespace separator for namespaced KeyMaps:
-NAMESPACE_SEP = sys.intern(':')
+NAMESPACE_SEP = sys.intern(os.pathsep)
 
 # The PATH environment variable, with a sensible default:
 PYTHON_BIN = os.path.join(sysconfig.get_path('data'), 'bin')
@@ -73,10 +82,10 @@ PATH = os.getenv("PATH", DEFAULT_PATH)
 φ = PARTIAL = sys.intern("<Partial>")
 
 # The name of this project
-PROJECT_NAME = sys.intern('clu')
+PROJECT_NAME = APPNAME
 
 # Path to the projects’ root package directory:
-PROJECT_PATH = sys.intern(os.path.join(BASEPATH, PROJECT_NAME))
+PROJECT_PATH = sys.intern(os.path.join(BASEPATH, APPNAME))
 
 # Determine if our Python is three’d up:
 PY3 = sys.version_info.major > 2
@@ -91,6 +100,9 @@ PYTHON_VERSION = float("%s%s%s" % (sys.version_info.major, os.extsep,
 # Qualifier for qualified-name operations:
 QUALIFIER = sys.intern(os.extsep)
 
+# Delimiter for repr-strings indicating instance IDs:
+REPR_DELIMITER = sys.intern('@')
+
 # List of Python’s built-in singleton types:
 NoneType = type(None)
 EllipsisType = type(Ellipsis)
@@ -102,7 +114,7 @@ SINGLETON_TYPES = (bool, NoneType, EllipsisType, NotImplementedType)
 STRINGPAIR = sys.intern("{!s} : {!s}")
 
 # Path to the script directory:
-SCRIPT_PATH = sys.intern(os.path.join(BASEPATH, 'clu', 'scripts'))
+SCRIPT_PATH = sys.intern(os.path.join(BASEPATH, APPNAME, 'scripts'))
 
 # Path to the project tests:
 TEST_PATH = sys.intern(os.path.join(BASEPATH, 'tests'))
@@ -152,15 +164,18 @@ pytuple.__lambda_name__ = λ # type: ignore
 pytuple.__qualname__ = pytuple.__name__ = 'pytuple'
 pytuple.__doc__ = "pytuple(*attrs) → turns ('do', 're', 'mi') into ('__do__', '__re__', '__mi__')"
 
-__all__ = ('BASEPATH',
+__all__ = ('APPNAME',
+           'BASEPATH',
            'BUILTINS',
            'CPYTHON',
            'DEBUG',
            'DELETE_FLAG',
            'DEFAULT_TERMINAL_WIDTH',
+           'DOLLA',
            'DYNAMIC_MODULE_PREFIX',
            'ENCODING',
            'ENVIRONS_SEP',
+           'EXPORTER_NAME',
            'FILE_ARGUMENT_NAMES',
            'HOSTNAME',
            'LAMBDA', 'λ',
@@ -172,6 +187,7 @@ __all__ = ('BASEPATH',
            'PY3', 'PYPY',
            'PYTHON_VERSION',
            'QUALIFIER',
+           'REPR_DELIMITER',
            'SEPARATOR_WIDTH',
            'SINGLETON_TYPES',
            'STRINGPAIR',
