@@ -299,8 +299,8 @@ class Registry(abc.ABC, metaclass=clu.abstract.Slotted):
         """ Return a specific registered class from the registry,
             given an “appname”, like e.g:
             
-                from clu import exporting
-                assert Registry['clu'] is exporting.Exporter
+                >>> from clu import exporting
+                >>> assert Registry['clu'] is exporting.Exporter
         """
         return cls.for_appname(key)
     
@@ -340,16 +340,36 @@ class Registry(abc.ABC, metaclass=clu.abstract.Slotted):
         """
         return search_modules(thing, *cls.all_modules())[0]
 
+class ExporterTypeRepr(clu.abstract.BasePath):
+    
+    """ At the time of writing, type-specific “__repr__(…)” definitions
+        require the use of a metaclass – soooooooo…
+    """
+    
+    def __repr__(cls):
+        from clu.naming import qualified_name
+        appname = getattr(cls, 'appname', None)
+        basepath = getattr(cls, 'basepath', None)
+        qualname = qualified_name(cls)
+        if not appname and not basepath:
+            return f"<class “{qualname}”>"
+        if not appname:
+            return f"<class “{qualname}”, basepath=“{basepath}”>"
+        if not basepath:
+            return f"<class “{qualname}”, appname=“{appname}”>"
+        return f"<class “{qualname}”, appname=“{appname}”, basepath=“{basepath}”>"
+
 class ExporterBase(collections.abc.MutableMapping,
+                   clu.abstract.ReprWrapper,
                    contextlib.AbstractContextManager,
-                   Registry, metaclass=clu.abstract.Prefix):
+                   Registry, metaclass=ExporterTypeRepr):
     
     """ The base class for “clu.exporting.Exporter”. Override this
         class in your own project to use the CLU exporting mechanism –
         q.v. “clu.exporting.Exporter” docstring sub.
         
-        This class uses the “clu.abstract.Prefix” metaclass, which
-        automatically adds a “prefix” class attribute, as well as
+        This class uses the “clu.abstract.BasePath” metaclass, which
+        automatically adds a “basepath” class attribute, as well as
         the “clu.exporting.Registry” mixin, which keeps a registry
         containing it and all of its derived subclasses, and furnishes
         the “instances” weak-value dictionary for instance registration.
@@ -360,7 +380,7 @@ class ExporterBase(collections.abc.MutableMapping,
     def __new__(cls, *args, path=None, dotpath=None, **kwargs):
         
         putative = path_to_dotpath(path,
-                   relative_to=cls.prefix) or dotpath
+                   relative_to=cls.basepath) or dotpath
         
         if putative is not None:
             if putative in cls.instances:
@@ -385,8 +405,8 @@ class ExporterBase(collections.abc.MutableMapping,
         """ Return a specific Exporter instance from the registry,
             given a dotted module path, like e.g:
             
-                from clu import naming
-                assert Exporter['clu.naming'] == naming.exporter
+                >>> from clu import naming
+                >>> assert Exporter['clu.naming'] == naming.exporter
         """
         # N.B. you are theoretically “not supposed” to use the
         # “__class_getitem__” method for anything whatsoever, and
@@ -509,22 +529,22 @@ class ExporterBase(collections.abc.MutableMapping,
             It looks better if this method is decoupled from its parent
             instance, to wit:
             
-                exporter = Exporter()
-                export = exporter.decorator() # q.v. “decorator()” sub.
+                >>> exporter = Exporter()
+                >>> export = exporter.decorator() # q.v. “decorator()” sub.
             
             Use `export` as a decorator to a function definition:
                 
-                @export
-                def yo_dogg(i_heard=None):
-                    …
+                >>> @export
+                >>> def yo_dogg(i_heard=None):
+                >>>     …
                 
             … or manually, to export anything that doesn’t have a name:
                 
-                yo_dogg = lambda i_heard=None: …
-                dogg_heard_index = ( ¬ ) 
+                >>> yo_dogg = lambda i_heard=None: …
+                >>> dogg_heard_index = ( ¬ ) 
                 
-                export(yo_dogg,             name="yo_dogg")
-                export(dogg_heard_index,    name="dogg_heard_index")
+                >>> export(yo_dogg,             name="yo_dogg")
+                >>> export(dogg_heard_index,    name="dogg_heard_index")
             
         """
         # Try to determine the thing’s name – deferring to anything passed:
@@ -583,12 +603,12 @@ class ExporterBase(collections.abc.MutableMapping,
         """ Return a reference to this Exporter instances’ “export”
             method, suitable for use as a decorator, e.g.:
             
-                export = exporter.decorator()
+                >>> export = exporter.decorator()
                 
-                @export
-                def yodogg():
-                    ''' Yo dogg, I heard you like exporting '''
-                    …
+                >>> @export
+                >>> def yodogg():
+                >>>     ''' Yo dogg, I heard you like exporting '''
+                >>>     …
             
             … This should be done near the beginning of a module,
             to facilitate marking functions and other objects to be
@@ -607,7 +627,7 @@ class ExporterBase(collections.abc.MutableMapping,
     def all_and_dir(self, *additionals):
         """ Assign a modules’ __all__ and __dir__ values, e.g.:
             
-                __all__, __dir__ = exporter.all_and_dir()
+                >>> __all__, __dir__ = exporter.all_and_dir()
             
             … This should be done near the end of a module, after
             all calls to `exporter.export(…)` (aka @export) have
@@ -619,7 +639,7 @@ class ExporterBase(collections.abc.MutableMapping,
     def dir_and_all(self, *additionals):
         """ Assign a modules’ __dir__ and __all__ values, e.g.:
             
-                __dir__, __all__ = exporter.dir_and_all()
+                >>> __dir__, __all__ = exporter.dir_and_all()
             
             … This should be done near the end of a module, after
             all calls to `exporter.export(…)` (aka @export) have
@@ -643,6 +663,16 @@ class ExporterBase(collections.abc.MutableMapping,
             return importlib.import_module(self.dotpath)
         return None
     
+    fields = ('appname', 'basepath', 'path', 'dotpath')
+    
+    def inner_repr(self):
+        """ Stringify a subset of the Exporter instances’ fields. """
+        from clu.repr import strfields
+        length = len(self)
+        return strfields(self, type(self).fields,
+                               try_callables=False,
+                               items=length)
+    
     def __enter__(self):
         return self.decorator()
     
@@ -710,17 +740,17 @@ class ExporterBase(collections.abc.MutableMapping,
                                                      'unregister'),
                            super(ExporterBase, self).__dir__()))
 
-class Exporter(ExporterBase, prefix=BASEPATH, appname=APPNAME):
+class Exporter(ExporterBase, basepath=BASEPATH, appname=APPNAME):
     
     """ A class representing a list of things for a module to export.
         
         This class is specifically germane to the CLU project – note
-        that the “prefix” class keyword is used to assign a value from
+        that the “basepath” class keyword is used to assign a value from
         the CLU constants module.
         
         Users of CLU who wish to use the Exporter mechanism in their
         own projects should create a subclass of ExporterBase of their
-        own. Like this one, it need only assign the “prefix” class
+        own. Like this one, it need only assign the “basepath” class
         keyword; it is unnecessary (but OK!) to define further methods,
         properties, class constants, and whatnot.
         
@@ -736,7 +766,7 @@ class Exporter(ExporterBase, prefix=BASEPATH, appname=APPNAME):
         you desire a class with a working “__dict__” attribute for
         some reason, you’ll need to specify:
         
-            __slots__ = tuplize('__dict__')
+            >>> __slots__ = tuplize('__dict__')
         
         … in your class (or an equivalent).
     """
@@ -746,9 +776,11 @@ class Exporter(ExporterBase, prefix=BASEPATH, appname=APPNAME):
 exporter = Exporter(path=__file__)
 
 with exporter as export:
+    
     export(itermodule)
     export(moduleids)
     export(itermoduleids)
+    export(Modulespace)
     export(search_by_id)
     export(search_for_name)
     export(search_for_module)
@@ -758,6 +790,7 @@ with exporter as export:
     
     # NO DOCS ALLOWED:
     export(Registry)
+    export(ExporterTypeRepr)
     export(ExporterBase)
     export(Exporter) # hahaaaaa
 
